import { Injectable } from '@angular/core';

import { HttpClient } from '@angular/common/http';

import { Observable } from 'rxjs/Observable';

import { forkJoin } from "rxjs/observable/forkJoin";

import { map } from 'rxjs/operators';


const CHANNEL_ID = 92737529;


@Injectable()
export class ImagesService {
    constructor(private http: HttpClient) { }

    getBadges(): Observable<any> {

        return forkJoin([
            this.http.get('https://badges.twitch.tv/v1/badges/global/display'),
            this.http.get('https://badges.twitch.tv/v1/badges/channels/' + CHANNEL_ID + '/display')
        ]).pipe(
            map((res: any[]) => {
                let sets = Object.assign({}, res[0].badge_sets, res[1].badge_sets);
                let badges = [];

                for (let set of Object.keys(sets)) {
                    let versions = sets[set].versions;
                    for (let ver of Object.keys(versions)) {
                        badges.push({
                            id: set + ':' + ver,
                            title: versions[ver].title,
                            url: versions[ver].image_url_1x
                        });
                    }
                }

                return badges;
            })
        );
    }

    getEmotes(): Observable<any> {
        return this.http.get('/comments/api/emotes').pipe(
            map((res: any[]) => {
                return res.map((emote: any) => ({
                    id: emote.id,
                    title: emote.code,
                    url: 'https://static-cdn.jtvnw.net/emoticons/v1/' + emote.id + '/1.0'
                }));
            })
        );
    }
}
